@@ -1,5 +1,5 @@
 // Copyright (c) HashiCorp, Inc.
-// SPDX-License-Identifier: MPL-2.0
+// SPDX-License-Identifier: BUSL-1.1
 
 package funcs
 
@@ -40,6 +40,7 @@ var LengthFunc = function.New(&function.Spec{
 		coll := args[0]
 		collTy := args[0].Type()
 		marks := coll.Marks()
+
 		switch {
 		case collTy == cty.DynamicPseudoType:
 			return cty.UnknownVal(cty.Number).WithMarks(marks), nil
@@ -222,14 +223,16 @@ var IndexFunc = function.New(&function.Spec{
 var LookupFunc = function.New(&function.Spec{
 	Params: []function.Parameter{
 		{
-			Name:        "inputMap",
-			Type:        cty.DynamicPseudoType,
-			AllowMarked: true,
+			Name:         "inputMap",
+			Type:         cty.DynamicPseudoType,
+			AllowMarked:  true,
+			AllowUnknown: true,
 		},
 		{
-			Name:        "key",
-			Type:        cty.String,
-			AllowMarked: true,
+			Name:         "key",
+			Type:         cty.String,
+			AllowMarked:  true,
+			AllowUnknown: true,
 		},
 	},
 	VarParam: &function.Parameter{
@@ -276,7 +279,7 @@ var LookupFunc = function.New(&function.Spec{
 		}
 	},
 	Impl: func(args []cty.Value, retType cty.Type) (ret cty.Value, err error) {
-		var defaultVal cty.Value
+		defaultVal := cty.NullVal(retType)
 		defaultValueSet := false
 
 		if len(args) == 3 {
@@ -297,12 +300,13 @@ var LookupFunc = function.New(&function.Spec{
 		if len(keyMarks) > 0 {
 			markses = append(markses, keyMarks)
 		}
-		lookupKey := keyVal.AsString()
 
-		if !mapVar.IsKnown() {
+		if !(mapVar.IsKnown() && keyVal.IsKnown()) {
 			return cty.UnknownVal(retType).WithMarks(markses...), nil
 		}
 
+		lookupKey := keyVal.AsString()
+
 		if mapVar.Type().IsObjectType() {
 			if mapVar.Type().HasAttribute(lookupKey) {
 				return mapVar.GetAttr(lookupKey).WithMarks(markses...), nil
