@@ -1,5 +1,5 @@
 // Copyright (c) HashiCorp, Inc.
-// SPDX-License-Identifier: MPL-2.0
+// SPDX-License-Identifier: BUSL-1.1
 
 package funcs
 
@@ -169,6 +169,10 @@ func TestLength(t *testing.T) {
 			}).Mark("secret"),
 			cty.NumberIntVal(3).Mark("secret"),
 		},
+		{ // Marked objects return a marked length
+			cty.UnknownVal(cty.String).Mark("secret"),
+			cty.UnknownVal(cty.Number).Refine().NotNull().NumberRangeLowerBound(cty.NumberIntVal(0), true).NewValue().Mark("secret"),
+		},
 		{ // Marks on object attribute values do not propagate
 			cty.ObjectVal(map[string]cty.Value{
 				"a": cty.StringVal("hello").Mark("a"),
@@ -813,7 +817,7 @@ func TestLookup(t *testing.T) {
 			cty.StringVal("beep").Mark("a"),
 			false,
 		},
-		{ // apply collection marks to unknown return vaue
+		{ // apply collection marks to unknown return value
 			[]cty.Value{
 				cty.MapVal(map[string]cty.Value{
 					"boop": cty.StringVal("beep"),
@@ -884,6 +888,15 @@ func TestLookup(t *testing.T) {
 			cty.StringVal("beep").Mark("a"),
 			false,
 		},
+		{ // propagate marks from unknown map
+			[]cty.Value{
+				cty.UnknownVal(cty.Map(cty.String)).Mark("a"),
+				cty.StringVal("boop").Mark("b"),
+				cty.StringVal("nope"),
+			},
+			cty.UnknownVal(cty.String).Mark("a").Mark("b"),
+			false,
+		},
 	}
 
 	for _, test := range tests {
@@ -1727,7 +1740,7 @@ func TestTranspose(t *testing.T) {
 			cty.NilVal,
 			true,
 		},
-		{ // marks (deep or shallow) on any elements will propegate to the entire return value
+		{ // marks (deep or shallow) on any elements will propagate to the entire return value
 			cty.MapVal(map[string]cty.Value{
 				"key1": cty.ListVal([]cty.Value{
 					cty.StringVal("a").Mark("beep"), // mark on the inner list element
