@@ -65,6 +65,7 @@ func (p *Parser) LoadConfigDir(baseDir, dir string) (*Module, hcl.Diagnostics) {
 	}
 
 	mod := NewEmptyModule()
+	mod.overrideFilenames = make([]string, len(overrides))
 
 	for _, path := range primaries {
 		f, loadDiags := p.loadHCLFile(baseDir, path)
@@ -78,7 +79,7 @@ func (p *Parser) LoadConfigDir(baseDir, dir string) (*Module, hcl.Diagnostics) {
 		mod.Sources[realPath] = f.Bytes
 		mod.Files[realPath] = f
 	}
-	for _, path := range overrides {
+	for idx, path := range overrides {
 		f, loadDiags := p.loadHCLFile(baseDir, path)
 		diags = diags.Extend(loadDiags)
 		if loadDiags.HasErrors() {
@@ -89,7 +90,10 @@ func (p *Parser) LoadConfigDir(baseDir, dir string) (*Module, hcl.Diagnostics) {
 		mod.overrides[realPath] = f
 		mod.Sources[realPath] = f.Bytes
 		mod.Files[realPath] = f
+		mod.overrideFilenames[idx] = realPath
 	}
+	// Overrides are processed in order first by filename (in lexicographical order)
+	sort.Strings(mod.overrideFilenames)
 	if diags.HasErrors() {
 		return mod, diags
 	}
@@ -237,12 +241,19 @@ func (p *Parser) IsConfigDir(baseDir, path string) bool {
 	return (len(primaryPaths) + len(overridePaths)) > 0
 }
 
+// Exists returns true if the given path exists in fs.
+func (p *Parser) Exists(path string) bool {
+	_, err := p.fs.Stat(path)
+	return err == nil
+}
+
 func (p *Parser) configDirFiles(baseDir, dir string) (primary, override []string, diags hcl.Diagnostics) {
 	infos, err := p.fs.ReadDir(dir)
 	if err != nil {
 		diags = append(diags, &hcl.Diagnostic{
 			Severity: hcl.DiagError,
 			Summary:  "Failed to read module directory",
+			Subject:  &hcl.Range{},
 			Detail:   fmt.Sprintf("Module directory %s does not exist or cannot be read.", filepath.Join(baseDir, dir)),
 		})
 		return
@@ -280,6 +291,7 @@ func (p *Parser) autoLoadValuesDirFiles(baseDir, dir string) (files []string, di
 		diags = append(diags, &hcl.Diagnostic{
 			Severity: hcl.DiagError,
 			Summary:  "Failed to read module directory",
+			Subject:  &hcl.Range{},
 			Detail:   fmt.Sprintf("Module directory %s does not exist or cannot be read.", filepath.Join(baseDir, dir)),
 		})
 		return nil, diags
